Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java')
-rw-r--r--org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java22
1 files changed, 20 insertions, 2 deletions
diff --git a/org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java b/org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java
index 5ac879cf6..e29de0941 100644
--- a/org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java
+++ b/org.eclipse.debug.core/core/org/eclipse/debug/core/Launch.java
@@ -125,6 +125,7 @@ public class Launch extends PlatformObject implements ILaunch {
* or <code>null</code> if none
* @param target the debug target created by this launch, or <code>null</code>
* if none
+ * @deprecated to be removed
*/
public Launch(ILaunchConfiguration launchConfiguration, String mode, ISourceLocator locator, IProcess[] processes, IDebugTarget target) {
setLauncher(null);
@@ -137,6 +138,23 @@ public class Launch extends PlatformObject implements ILaunch {
}
/**
+ * Constructs a launch with the specified attributes.
+ *
+ * @param launchConfiguration the configuration that was launched
+ * @param mode the mode of this launch - run or debug (constants
+ * defined by <code>ILaunchManager</code>)
+ * @param locator the source locator to use for this debug session, or
+ * <code>null</code> if not supported
+ */
+ public Launch(ILaunchConfiguration launchConfiguration, String mode, ISourceLocator locator) {
+ setLauncher(null);
+ setElement(launchConfiguration);
+ setSourceLocator(locator);
+ setLaunchMode(mode);
+ fSuppressChange = false;
+ }
+
+ /**
* @see org.eclipse.debug.core.model.ITerminate#canTerminate()
*/
public final boolean canTerminate() {
@@ -207,7 +225,7 @@ public class Launch extends PlatformObject implements ILaunch {
* Returns the processes associated with this
* launch, in its internal form - a list.
*
- * @return list or processes
+ * @return list of processes
*/
protected List getProcesses0() {
return fProcesses;
@@ -421,7 +439,7 @@ public class Launch extends PlatformObject implements ILaunch {
}
/**
* Adds the given processes to this lanuch.
*
* @param processes processes to add
*/
@@ -421,7 +439,7 @@ public class Launch extends PlatformObject implements ILaunch {
}
/**
- * Adds the given processes to this lanuch.
+ * Adds the given processes to this launch.
*
* @param processes processes to add

Back to the top